==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/listener/KafkaListenerPlainFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.model.networking.NetworkPolicyPeer;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface KafkaListenerPlainFluent<A extends KafkaListenerPlainFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAuth instead.
 * @return The buildable object.
 */
@Deprecated public KafkaListenerAuthentication getAuth();
    public KafkaListenerAuthentication buildAuth();
    public A withAuth(KafkaListenerAuthentication auth);
    public Boolean hasAuth();
    public A withKafkaListenerAuthenticationOAuth(KafkaListenerAuthenticationOAuth kafkaListenerAuthenticationOAuth);
    public KafkaListenerPlainFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuth();
    public KafkaListenerPlainFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuthLike(KafkaListenerAuthenticationOAuth item);
    public A withKafkaListenerAuthenticationTlsAuth(KafkaListenerAuthenticationTls kafkaListenerAuthenticationTlsAuth);
    public KafkaListenerPlainFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuth();
    public KafkaListenerPlainFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuthLike(KafkaListenerAuthenticationTls item);
    public A withKafkaListenerAuthenticationScramSha512Auth(KafkaListenerAuthenticationScramSha512 kafkaListenerAuthenticationScramSha512Auth);
    public KafkaListenerPlainFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512Auth();
    public KafkaListenerPlainFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512AuthLike(KafkaListenerAuthenticationScramSha512 item);
    public A addToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A setToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A addToNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A addAllToNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public A removeFromNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A removeAllFromNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public List<NetworkPolicyPeer> getNetworkPolicyPeers();
    public NetworkPolicyPeer getNetworkPolicyPeer(int index);
    public NetworkPolicyPeer getFirstNetworkPolicyPeer();
    public NetworkPolicyPeer getLastNetworkPolicyPeer();
    public NetworkPolicyPeer getMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public Boolean hasMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public A withNetworkPolicyPeers(List<NetworkPolicyPeer> networkPolicyPeers);
    public A withNetworkPolicyPeers(NetworkPolicyPeer... networkPolicyPeers);
    public Boolean hasNetworkPolicyPeers();

    public interface KafkaListenerAuthenticationOAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationOAuthFluent<KafkaListenerPlainFluent.KafkaListenerAuthenticationOAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationOAuth();
}
    public interface KafkaListenerAuthenticationTlsAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationTlsFluent<KafkaListenerPlainFluent.KafkaListenerAuthenticationTlsAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationTlsAuth();
}
    public interface KafkaListenerAuthenticationScramSha512AuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationScramSha512Fluent<KafkaListenerPlainFluent.KafkaListenerAuthenticationScramSha512AuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationScramSha512Auth();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/listener/KafkaListenerPlainFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeer;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface KafkaListenerPlainFluent<A extends KafkaListenerPlainFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAuth instead.
 * @return The buildable object.
 */
@Deprecated public KafkaListenerAuthentication getAuth();
    public KafkaListenerAuthentication buildAuth();
    public A withAuth(KafkaListenerAuthentication auth);
    public Boolean hasAuth();
    public A withKafkaListenerAuthenticationOAuth(KafkaListenerAuthenticationOAuth kafkaListenerAuthenticationOAuth);
    public KafkaListenerPlainFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuth();
    public KafkaListenerPlainFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuthLike(KafkaListenerAuthenticationOAuth item);
    public A withKafkaListenerAuthenticationTlsAuth(KafkaListenerAuthenticationTls kafkaListenerAuthenticationTlsAuth);
    public KafkaListenerPlainFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuth();
    public KafkaListenerPlainFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuthLike(KafkaListenerAuthenticationTls item);
    public A withKafkaListenerAuthenticationScramSha512Auth(KafkaListenerAuthenticationScramSha512 kafkaListenerAuthenticationScramSha512Auth);
    public KafkaListenerPlainFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512Auth();
    public KafkaListenerPlainFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512AuthLike(KafkaListenerAuthenticationScramSha512 item);
    public A addToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A setToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A addToNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A addAllToNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public A removeFromNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A removeAllFromNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public java.util.List<NetworkPolicyPeer> getNetworkPolicyPeers();
    public NetworkPolicyPeer getNetworkPolicyPeer(int index);
    public NetworkPolicyPeer getFirstNetworkPolicyPeer();
    public NetworkPolicyPeer getLastNetworkPolicyPeer();
    public NetworkPolicyPeer getMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public Boolean hasMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public A withNetworkPolicyPeers(java.util.List<NetworkPolicyPeer> networkPolicyPeers);
    public A withNetworkPolicyPeers(NetworkPolicyPeer... networkPolicyPeers);
    public Boolean hasNetworkPolicyPeers();

    public interface KafkaListenerAuthenticationOAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationOAuthFluent<KafkaListenerPlainFluent.KafkaListenerAuthenticationOAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationOAuth();
}
    public interface KafkaListenerAuthenticationTlsAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationTlsFluent<KafkaListenerPlainFluent.KafkaListenerAuthenticationTlsAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationTlsAuth();
}
    public interface KafkaListenerAuthenticationScramSha512AuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationScramSha512Fluent<KafkaListenerPlainFluent.KafkaListenerAuthenticationScramSha512AuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationScramSha512Auth();
}


}
